function u=newton_2(F,u0,tol,maxit)
%_______________________________________________
%
%  NEWTON_2
%_______________________________________________
%
% Solves the system of two non-linear equations 
% F1(x,y)=0, F2(x,y)=0 using 2D Newton method

% Input arguments:

% maxit - max number of iterations
% tol   - tolerance
% u0    - coordinates of the initial point, [x0,y0]
% F     - the name (string) of a user supplied function Z=F(u)
%         which, for a given u=[x,y] returns 2x3 matrix 
%         containing the values of F1, F2, and their derivatives,
%         Z=[F1  dF1/dx  dF1/dy
%            F2  dF2/dx  dF2/dy]

% Output arguments:
% u     - coordinates [x,y] of the solution found 
u=u0.';
i=1;
while i<=maxit
    Z=feval(F,u);
    if abs(Z(1,1))<tol&abs(Z(2,1))<tol
        break
    end
    Z1=[Z(1,1);Z(2,1)];
    Z2=[[Z(1,2),Z(1,3)];[Z(2,2),Z(2,3)]];
    if det(Z2)==0
        return
    end
    u=u-Z2\Z1;
    i=i+1;
end